==> pysenti-0.1.3.tar.gz: pysenti-0.1.3/setup.py <==
# -*- coding: utf-8 -*-
"""
@author:XuMing（xuming624@qq.com)
@description:
"""
from __future__ import print_function

import sys
from codecs import open

from setuptools import setup, find_packages

from pysenti import __version__

if sys.version_info < (3,):
    sys.exit('Sorry, Python3 is required for pysenti')

with open('README.md', 'r', encoding='utf-8') as f:
    readme = f.read()

with open('LICENSE', 'r', encoding='utf-8') as f:
    license = f.read()

with open('requirements.txt', 'r', encoding='utf-8') as f:
    reqs = f.read()

setup(
    name='pysenti',
    version=__version__,
    description='Chinese Sentiment Classifier',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='XuMing',
    author_email='xuming624@qq.com',
    url='https://github.com/shibing624/pysenti',
    license="Apache 2.0",
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Natural Language :: Chinese (Simplified)',
        'Natural Language :: Chinese (Traditional)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Text Processing',
        'Topic :: Text Processing :: Indexing',
        'Topic :: Text Processing :: Linguistic',
    ],
    keywords='NLP,sentiment-classifier,sentiment-classification,pysenti',
    install_requires=reqs.strip().split('\n'),
    packages=find_packages(exclude=['tests']),
    package_dir={'pysenti': 'pysenti'},
    package_data={
        'pysenti': ['*.*', '../LICENSE', '../README.*', '../*.txt', 'data/*'],
    },
    test_suite='tests',
)

==> pysenti-0.1.6.tar.gz: pysenti-0.1.6/setup.py <==
# -*- coding: utf-8 -*-
"""
@author:XuMing（xuming624@qq.com)
@description:
"""
from __future__ import print_function

from codecs import open

from setuptools import setup, find_packages

from pysenti import __version__

with open('README.md', 'r', encoding='utf-8') as f:
    readme = f.read()

with open('LICENSE', 'r', encoding='utf-8') as f:
    license = f.read()

with open('requirements.txt', 'r', encoding='utf-8') as f:
    reqs = f.read()

setup(
    name='pysenti',
    version=__version__,
    description='Chinese Sentiment Classifier',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='XuMing',
    author_email='xuming624@qq.com',
    url='https://github.com/shibing624/pysenti',
    license="Apache 2.0",
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Natural Language :: Chinese (Simplified)',
        'Natural Language :: Chinese (Traditional)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Text Processing',
        'Topic :: Text Processing :: Indexing',
        'Topic :: Text Processing :: Linguistic',
    ],
    keywords='NLP,sentiment-classifier,sentiment-classification,pysenti',
    install_requires=reqs.strip().split('\n'),
    packages=find_packages(),
    package_dir={'pysenti': 'pysenti'},
    package_data={'pysenti': ['*.*', '../LICENSE', '../README.*', '../*.txt', 'data/*']}
)
